# Checkout GitHub Action

This composite GitHub Action allows you to **clone** and **check out** the current repository using the Git CLI. The action uses the GitHub-provided `GITHUB_TOKEN` for authentication, ensuring secure and seamless access.

## Features

- Clones the repository using HTTP.
- Checks out the specified branch or reference (`${{ github.ref }}`).
- Utilizes GitHub's built-in secrets for secure access.

## Usage

### Example Workflow

```yaml
name: Example Workflow

on:
  push:
    branches:
      - main

jobs:
  checkout-job:
    runs-on: ubuntu-latest
    steps:
      - name: Checkout Repository
        uses: ./
```

### Inputs

No custom inputs are required. The action uses environment variables provided by GitHub Actions:

| Variable           | Description                                               |
|--------------------|-----------------------------------------------------------|
| `github.server_url` | The URL of the GitHub server.                             |
| `github.token`      | Automatically provided GitHub token for authentication.  |
| `github.repository` | The repository name (`owner/repo`).                      |
| `github.workspace`  | The working directory for the workflow.                  |
| `github.ref`        | The branch or tag to check out.                          |
